@@ -5,7 +5,7 @@ logger = getLogger(__name__)
 
 # Version is defined in pyproject.toml.
 # It's copied here to make it easier for client code to check the installed version.
-__version__ = '0.7.1'
+__version__ = '0.7.3'
 
 
 def get_placeholder_class(original_exception: Exception = None):
@@ -16,13 +16,18 @@ def get_placeholder_class(original_exception: Exception = None):
     class Placeholder:
         msg = 'Dependencies are not installed for this feature'
 
-        def __init__(self, *args, **kwargs):
+        def _log_error(self):
             logger.error(self.msg)
             raise original_exception or ImportError(self.msg)
 
+        def __init__(self, *args, **kwargs):
+            self._log_error()
+
         def __getattr__(self, *args, **kwargs):
-            logger.error(self.msg)
-            raise original_exception or ImportError(self.msg)
+            self._log_error()
+
+        def dumps(self, *args, **kwargs):
+            self._log_error()
 
     return Placeholder
 
