@@ -1,6 +1,5 @@
 """Common tests to run for all backends (BaseCache subclasses)"""
 import json
-import pytest
 from datetime import datetime
 from io import BytesIO
 from threading import Thread
@@ -8,7 +7,9 @@ from time import sleep, time
 from typing import Dict, Type
 from urllib.parse import parse_qs, urlparse
 
+import pytest
 import requests
+from requests.models import PreparedRequest
 
 from requests_cache import ALL_METHODS, CachedResponse, CachedSession
 from requests_cache.backends.base import BaseCache
@@ -46,8 +47,7 @@ class BaseCacheTest:
         kwargs.setdefault('serializer', 'pickle')
         backend = self.backend_class(CACHE_NAME, **self.init_kwargs, **kwargs)
         if clear:
-            backend.redirects.clear()
-            backend.responses.clear()
+            backend.clear()
 
         return CachedSession(backend=backend, **self.init_kwargs, **kwargs)
 
@@ -87,8 +87,10 @@ class BaseCacheTest:
 
     @pytest.mark.parametrize('n_redirects', range(1, 5))
     @pytest.mark.parametrize('endpoint', ['redirect', 'absolute-redirect', 'relative-redirect'])
-    def test_redirects(self, endpoint, n_redirects):
-        """Test all types of redirect endpoints with different numbers of consecutive redirects"""
+    def test_redirect_history(self, endpoint, n_redirects):
+        """Test redirect caching (in separate `redirects` cache) with all types of redirect endpoints,
+        using different numbers of consecutive redirects
+        """
         session = self.init_session()
         session.get(httpbin(f'{endpoint}/{n_redirects}'))
         r2 = session.get(httpbin('get'))
@@ -96,6 +98,18 @@ class BaseCacheTest:
         assert r2.from_cache is True
         assert len(session.cache.redirects) == n_redirects
 
+    @pytest.mark.parametrize('endpoint', ['redirect', 'absolute-redirect', 'relative-redirect'])
+    def test_redirect_responses(self, endpoint):
+        """Test redirect caching (in main `responses` cache) with all types of redirect endpoints"""
+        session = self.init_session(allowable_codes=(200, 302))
+        r1 = session.head(httpbin(f'{endpoint}/2'))
+        r2 = session.head(httpbin(f'{endpoint}/2'))
+
+        assert r2.from_cache is True
+        assert len(session.cache.redirects) == 0
+        assert isinstance(r1.next, PreparedRequest) and r1.next.url.endswith('redirect/1')
+        assert isinstance(r2.next, PreparedRequest) and r2.next.url.endswith('redirect/1')
+
     def test_cookies(self):
         session = self.init_session()
 
