@@ -3,7 +3,10 @@ from os.path import isfile
 from shutil import rmtree
 from tempfile import gettempdir
 
+import pytest
+
 from requests_cache.backends import FileCache, FileDict
+from requests_cache.serializers import SERIALIZERS, SerializerPipeline
 from tests.integration.base_cache_test import BaseCacheTest
 from tests.integration.base_storage_test import CACHE_NAME, BaseStorageTest
 
@@ -27,14 +30,21 @@ class TestFileDict(BaseStorageTest):
         assert not relative_path.startswith(gettempdir())
         assert temp_path.startswith(gettempdir())
 
-    def test_paths(self):
-        cache = self.storage_class(CACHE_NAME)
+    @pytest.mark.parametrize('serializer_name', SERIALIZERS.keys())
+    def test_paths(self, serializer_name):
+        if not isinstance(SERIALIZERS[serializer_name], SerializerPipeline):
+            pytest.skip(f'Dependencies not installed for {serializer_name}')
+
+        cache = self.storage_class(CACHE_NAME, serializer=serializer_name)
+        cache.clear()
         for i in range(self.num_instances):
             cache[f'key_{i}'] = f'value_{i}'
 
+        expected_extension = serializer_name.replace('pickle', 'pkl')
         assert len(list(cache.paths())) == self.num_instances
         for path in cache.paths():
             assert isfile(path)
+            assert path.endswith(f'.{expected_extension}')
 
 
 class TestFileCache(BaseCacheTest):
