@@ -1,7 +1,6 @@
 """CachedSession + BaseCache tests that use mocked responses only"""
 # TODO: This could be split up into some smaller test modules
 import json
-import pytest
 import sys
 import time
 from collections import UserDict, defaultdict
@@ -10,6 +9,7 @@ from pickle import PickleError
 from unittest.mock import patch
 from uuid import uuid4
 
+import pytest
 import requests
 from itsdangerous import Signer
 from itsdangerous.exc import BadSignature
@@ -315,13 +315,13 @@ def test_clear(mock_session):
     assert not mock_session.cache.has_url(MOCKED_URL_REDIRECT)
 
 
-def test_delete_response(mock_session):
+def test_delete_url(mock_session):
     mock_session.get(MOCKED_URL)
     mock_session.cache.delete_url(MOCKED_URL)
     assert not mock_session.cache.has_url(MOCKED_URL)
 
 
-def test_delete_nonexistent_response(mock_session):
+def test_delete_url__nonexistent_response(mock_session):
     """Deleting a response that was either already deleted (or never added) should fail silently"""
     mock_session.cache.delete_url(MOCKED_URL)
 
@@ -331,7 +331,7 @@ def test_delete_nonexistent_response(mock_session):
     mock_session.cache.delete_url(MOCKED_URL)  # Should fail silently
 
 
-def test_delete_redirect(mock_session):
+def test_delete_url__redirect(mock_session):
     mock_session.get(MOCKED_URL_REDIRECT)
     assert mock_session.cache.has_url(MOCKED_URL_REDIRECT)
 
@@ -339,6 +339,16 @@ def test_delete_redirect(mock_session):
     assert not mock_session.cache.has_url(MOCKED_URL_REDIRECT)
 
 
+def test_delete_urls(mock_session):
+    urls = [MOCKED_URL, MOCKED_URL_JSON, MOCKED_URL_REDIRECT]
+    for url in urls:
+        mock_session.get(url)
+
+    mock_session.cache.delete_urls(urls)
+    for url in urls:
+        assert not mock_session.cache.has_url(MOCKED_URL_REDIRECT)
+
+
 def test_save_response_manual(mock_session):
     response = mock_session.get(MOCKED_URL)
     mock_session.cache.clear()
@@ -352,6 +362,7 @@ def test_response_defaults(mock_session):
     response_2 = mock_session.get(MOCKED_URL)
     response_3 = mock_session.get(MOCKED_URL)
 
+    assert response_1.cache_key.startswith('4398752d')
     assert response_1.created_at is None
     assert response_1.expires is None
     assert response_1.from_cache is False
@@ -359,6 +370,7 @@ def test_response_defaults(mock_session):
 
     assert isinstance(response_2.created_at, datetime)
     assert isinstance(response_2.expires, datetime)
+    assert response_2.cache_key.startswith('4398752d')
     assert response_2.created_at == response_3.created_at
     assert response_2.expires == response_3.expires
     assert response_2.from_cache is response_3.from_cache is True
